#
# spec file for package kdenlive
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define mlt_version 6.0.0

Name:           kdenlive
Version:        16.08.2
Release:        1.1
Summary:        Non-linear video editor
License:        GPL-3.0+
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            http://www.kdenlive.org/
Source0:        http://download.kde.org/stable/applications/16.08.2/src/%{name}-%{version}.tar.xz
Patch1:         use-mlt_datadir.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  shared-mime-info
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  libmlt-devel
BuildRequires:  pkgconfig(mlt++) >= %{mlt_version}
BuildRequires:  pkgconfig(mlt-framework) >= %{mlt_version}
BuildRequires:  pkgconfig(x11)
BuildRequires:  extra-cmake-modules
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Script)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  kconfig-devel
BuildRequires:  karchive-devel
BuildRequires:  kcoreaddons-devel
BuildRequires:  kconfigwidgets-devel
BuildRequires:  kdbusaddons-devel
BuildRequires:  kio-devel
BuildRequires:  kdoctools-devel
BuildRequires:  knotifications-devel
BuildRequires:  kwidgetsaddons-devel
BuildRequires:  kplotting-devel
BuildRequires:  knotifyconfig-devel
BuildRequires:  knewstuff-devel
BuildRequires:  kxmlgui-devel
BuildRequires:  kiconthemes-devel
BuildRequires:  ktextwidgets-devel
BuildRequires:  kguiaddons-devel
BuildRequires:  kcrash-devel
%define melt_path %(pkg-config --variable=meltbin mlt-framework)
Requires:       %{melt_path}
# Waiting for the day all libraries have versioned symbols...
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libmlt++.so) --qf '%{NAME}') >= %{mlt_version}
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libmlt.so) --qf '%{NAME}') >= %{mlt_version}
# Without a few of the plugins it crashes on start
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libmlt.so) --qf '%{NAME}')-modules
# It requires the profiles
Requires:       %(rpm -qf $(readlink -qne %{_libdir}/libmlt.so) --qf '%{NAME}')-data
# It doesn't start without it (boo#994649)
Requires:       libqt5-qtquickcontrols
Recommends:     %{_bindir}/dvdauthor
Recommends:     %{_bindir}/dvgrab
Recommends:     %{_bindir}/ffmpeg
Recommends:     %{_bindir}/ffplay
Recommends:     %{_bindir}/genisoimage
%define mlt_soname %(pkg-config --variable=moduledir mlt-framework | sed 's/.*-\\([0-9]\\+\\)/\\1/')
Recommends:     mlt(%{mlt_soname})(avformat)
Obsoletes:      kdenlive5 < %{version}
Provides:       kdenlive5 = %{version}

%description
Kdenlive is a non-linear video editor for GNU/Linux and FreeBSD, which supports
DV, AVCHD (experimental support) and HDV editing. Kdenlive relies on several
other open source projects, such as FFmpeg and the MLT video framework. It was
designed to answer all needs, from basic video editing to semi-professional
work.

%prep
%setup -q
#patch1 -p1

%build
%cmake_kf5 -d build
%make_jobs

%install
%kf5_makeinstall -C build
%fdupes -s %{buildroot}

%post
%icon_theme_cache_post
%icon_theme_cache_post oxygen
%mime_database_post
%desktop_database_post

%postun
%desktop_database_postun
%mime_database_postun
%icon_theme_cache_postun oxygen
%icon_theme_cache_postun

%files
%defattr(0644,root,root,0755)
%doc AUTHORS COPYING README
%attr(0755,-,-) %{_bindir}/%{name}
%attr(0755,-,-) %{_bindir}/%{name}_render
%dir %_kf5_configkcfgdir
%_kf5_configkcfgdir/kdenlivesettings.kcfg
%_datadir/kdenlive/
%_mandir/man1/*
%_datadir/mime/packages/*
%_kf5_applicationsdir/org.kde.kdenlive.desktop
%_datadir/kxmlgui5/kdenlive/
%(config) %_kf5_configdir/*.knsrc
%_kf5_plugindir/mltpreview.so
%_datadir/knotifications5/kdenlive.notifyrc
%_kf5_servicesdir/mltpreview.desktop
%_kf5_htmldir/en/kdenlive/
%_kf5_appstreamdir/
%{_kf5_iconsdir}/hicolor/*/*/*

%changelog
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 19 2016 wbauer@tmo.at
- Require libqt5-qtquickcontrols, it doesn't start without it (boo#994649)
- Minimum required mlt version is 6.0.0 now
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.07.90.php
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Sat Jul  2 2016 fvogt@suse.com
- Update required MLT version to 0.9.8 to avoid failing builds
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sun Feb  7 2016 wbauer@tmo.at
- Add BuildRequires: pkgconfig(libv4l2) to fix boo#959174
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.07.90.php
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.2
  * KDE Applications 15.04.2
  * https://www.kde.org/announcements/announce-applications-15.04.2.php
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
- Drop upstreamed patches:
  * kdenlive-0.9.10-no_avformat.patch
- Renamed and adjusted patch
  * use-mlt_datadir.patch
* Thu Oct 16 2014 nico.kruber@gmail.com
- Update to 0.9.10
  + handle VBR encoding profiles, and use it!
  + video stabilizer: added new "vid.stab", removed older ones
  + environment variable MLT_PREFIX overrides profiles & melt path
  + several fixes for high dpi screens
  + change proxy profile, obsolete with libav
  + add SVG to image formats for slideshows
  + restore project render bitrate (#3326)
  + show proxy name in clipproperties
  + add link to MLT doc in render edit dialog (#3355)
  + update maximum track height (#3241)
  + resize render path box (#3300)
  + change transition settings layout (#3336)
  + heat colormap in spectrogram (#3142)
  + fix clip monitor switch on proxy creation end (#3308)
  + fix clip jobs (stabilize) operating on proxies (#3337)
  + fix timeline corruption by clip resize end + zoom change
  + fix title clip duration not taken into account (#3309)
  + fix timeline thumbs flicker when fully zoomed (#3247)
  + fix thumbnailer aspect ratio
  + fix fades for split audio (#3323)
  + fix transcoding (#3334)
  + fix 'Clip in Timeline' when project monitor is inactive (#3261)
  + fix audio analysis (use dynamic memory instead of stack)
  + fix render end notification
  + fix render timecode overlay (#3260)
  + set tooltip for monitor pause button (#3256)
  + fix slideshow clips adding 1 frame (#3289)
  + fix archive project icon (#3325)
  + fix compilation on armhf (#3345)
  + don't allow creating keyframes for "fixed" filters (#2956)
  + re-enable compilation on KDE < 4.5 (squeeze) (#3319)
  + re-enable Clip menu (fix bug #3347)
  + fix screen recording failure (#3358)
  + fix crash detected with undo/redo (bug #3240)
  + fix crash cutting group on a clip edge (#3312, #3350)
  + fix crash on image sequence (#3331)
  + fix crash in tracks config editor (#3367)
  + fix crash on audiofiles
  + fix crash on opening project file with images
  + fix warnings from static analyzers (cppcheck, krazy)
  + sort source files, easier to understand (for new developpers)
- Update kdenlive-0.9.2-mlt_datadir.patch to
  kdenlive-0.9.10-mlt_datadir.patch
- Update kdenlive-0.9.2-no_avformat.patch to
  kdenlive-0.9.10-no_avformat.patch
* Wed Jul  2 2014 fisiu@opensuse.org
- Build all translations.
* Wed May 21 2014 dap.darkness@gmail.com
- Update to 0.9.8
  + Fades: timeline shortcut now applies to video on clips
    containing video and audio;
  + Copy proxies with 'move project';
  + Remove the MLT processing threads option that never really
    worked;
  + Clean encoding profiles using MLT presets and profiles;
  + Support a custom suffix for FFmpeg binaries (mostly for
    packagers);
  + Make audio align work asynchronously;
  + Add support for JogShuttle on newer systems, make shuttle
    device selection more straightforward, add ProV2 keys;
  + Fix warnings from gcc, cppcheck, clang, scan-build: fixes
    many crashs & leaks;
  + Code cleanup (use const ref, fix includes, mem leaks,
    optimize...);
  + Fix keyframing messed up for some effects;
  + Fix timeline corruption when trying to move clip before 0;
  + Fix crash when closing title widget;
  + Fix thumbnails for image clips in timeline;
  + Fix crash on quick undo/redo (#3240);
  + Fix multithreading (#3186);
  + Fix some problems with transitions keyframes;
  + Fix scopes (#3052).
- Updated kdenlive-0.9.2-mlt_datadir.patch &
  kdenlive-0.9.2-no_avformat.patch.
* Sun Apr  7 2013 hrvoje.senjan@gmail.com
- Update to 0.9.6
  + Fix keyframes when cutting a clip / undoing a clip cut
  + Warn before overwriting .mlt stabilized file
  + Fix monitor confusion (clip monitor sometimes playing timeline)
  + Fix the Mono to Stereo effect UI
  + Fix proxy of playlist having wrong aspect ratio in some locales
  + Fix transition widget not correctly updated when resizing a
    transition
  + Fix DVD chapters broken when using an intro movie
  + Fix error message (No matching profile) poping up in render
    widget when everything was ok
  + Fix clip keyframes not showing on project load
  + Fix bug when moving guide (was not moving to the correct place)
  + Fix project corruption (wrong character) caused by some clip's
    metadata
  + Fix possible crash on track deletion
  + Fix timeline corruption when using spacer tool or overwrite edit
    mode
  + Fix possible crash when editing speed effect
  + Fix transition losing all its properties when moved
  + Fix crash when pressing del when editing animation in title
    widget
  + Fix crash when doing quick clip resize
  + Fix corruption when groups where overlapping
  + Fix corruption when adding a title clip where a transition already
    existed
  + Fix timeline preview corruption with some transitions
* Tue Feb  5 2013 reddwarf@opensuse.org
- Add missing BR: pkgconfig(libv4l2)
* Wed Jan 30 2013 reddwarf@opensuse.org
- Do not recommend recordmydesktop. It's not used any more.
- Update the minimum mlt version
- Reenable V4L support. The legal problem has been fixed.
* Wed Jan 30 2013 nico.kruber@gmail.com
- Update to 0.9.4
  + Rewritten DVD Wizard
  + Improved clip markers
  + Rewritten Screen Capture
  + Support for multiple streams clips
  + Clip analysis feature
  + Stability and Performance improvements
  - 8 features introduced
  - 124 bugs fixed
* Fri Nov 30 2012 reddwarf@opensuse.org
- Make it work with versioned melt binaries
- Add kdenlive-0.9.2-no_avformat.patch to support systems without
  the avformat plugin
* Thu Aug 16 2012 reddwarf@opensuse.org
- Recommend a package with the avformat module
* Mon Aug 13 2012 reddwarf@opensuse.org
- Require libmltX-modules and libmltX-data
* Sun Aug 12 2012 reddwarf@opensuse.org
- Add kdenlive-0.9.2-mlt_datadir.patch to use the correct MLT data
  dir by default
* Fri Jun  1 2012 reddwarf@opensuse.org
- Disable V4L support (bnc#765082). GPL-2.0 only, incompatible
  with GPL-3.0+ parts.
* Thu May 31 2012 reddwarf@opensuse.org
- Update to 0.9.2
  + Fix freeze when reloading previously missing clip
  + Fade effects lost when moving / resizing clip
  + Undoing change in clip crop start breaking clip
  + Make disabling of track effects possible
  + Fix slideshow clips not working
  + Fix crash on composite transition
  + Fix crash when opening stop motion widget
  + Fix rendering of projects created in another locale
  + Fix Firewire capture
* Tue May 15 2012 reddwarf@opensuse.org
- Update to 0.9
  * Improved effects workflow
  * Automatic audio alignment
  * Easy import of online resources
  * Usability improvements
  - Recording can now be monitored through the audio and color
    scopes, audio normalization can analyse audio for better
    results
  - Allow audio only recording
  - Clips can be sorted by date
  - New effects from MLT / frei0r: video stabilizers,
    IIR Blur, etc
  - Offline editing (Backup the project with proxy clips only to
    work on less powerful computers)
  * Read the ChangeLog file for a more complete list of changes
- Add %%icon_theme_cache_post and %%desktop_database_post macros and
  its dependencies as BuildRequires
- Update the BuildRequires
- Updates source tag with new URL
- Recommend genisoimage instead of mkisofs
* Fri May  4 2012 reddwarf@opensuse.org
- Change license from GPL-2.0+ to GPL-2.0 (bnc#760651)
* Mon Feb 27 2012 saschpe@suse.de
- Set SPDX-style license
* Sun Aug 23 2009 reddwarf@opensuse.org
- Initial package
